from pymatgen import Structure, MPRester
from pymatgen.core.structure import Structure
from atomate.vasp.database import VaspCalcDb
from pymatgen.analysis.ferroelectricity.polarization import Polarization, get_total_ionic_dipole

PATH_TO_MY_DB_JSON = '/work/04391/tg836903/stampede2/atomate/config/db.json'
atomate_db = VaspCalcDb.from_db_file(PATH_TO_MY_DB_JSON)



def find_polar_calc(pretty, task_label=''):
    calc = atomate_db.collection.find_one({'task_label': task_label,
        'formula_pretty': pretty})
    out = calc['calcs_reversed'][0]['output']['outcar']
    struct = Structure.from_dict(calc['calcs_reversed'][0]['input']['structure'])
    zval = calc['calcs_reversed'][0]['output']['outcar']['zval_dict']
    return (out, struct, zval)
    

    
outcars = []
structures = []
zval_dicts = []
temp = find_polar_calc('LaSnNO2', task_label='_polar_polarization')
outcars.append(temp[0])
structures.append(temp[1])
zval_dicts.append(temp[2])
 
for i in range(8):
    temp = find_polar_calc('LaSnNO2', task_label='_interpolation_' + str(i+1) + '_polarization')
    outcars.append(temp[0])
    structures.append(temp[1])
    zval_dicts.append(temp[2])
    
temp = find_polar_calc('LaSnNO2', task_label='_nonpolar_polarization')
outcars.append(temp[0])
structures.append(temp[1])
zval_dicts.append(temp[2])


#works taking p_ions directly from OUTCAR
#fails when I get_total_ionic_dipole
#But, note that get_total_ionic_dipole still works when I feed the OUTCARS and POSCARS
#to it through Pymatgen, things only break when they go through Atomate first
p_elecs = [outcar['p_elec'] for outcar in outcars]
bad_p_ions = [get_total_ionic_dipole(structures[i], zval_dicts[i]) for i in range(len(structures))]
good_p_ions = [outcar['p_ion'] for outcar in outcars]
bad_pol = Polarization(p_elecs, bad_p_ions, structures)
print(bad_pol.get_same_branch_polarization_data(convert_to_muC_per_cm2=True))
good_pol = Polarization(p_elecs, good_p_ions, structures)
print(good_pol.get_same_branch_polarization_data(convert_to_muC_per_cm2=True))

